ioexport

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Overview

Package ioexport implements the Exporter interface for exporting PostgreSQL gnames data to SFGA SQLite format files. This is an impure I/O package that reads from PostgreSQL and writes SFGA archives.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllSourcesFailedError

func AllSourcesFailedError(count int) error

AllSourcesFailedError creates an error for when all sources fail to export.

func CompanionYAMLError

func CompanionYAMLError(path string, err error) error

CompanionYAMLError creates an error for when the companion .yaml file cannot be written alongside the exported SFGA archive.

func New

func New(cfg *config.Config, op db.Operator) gndb.Exporter

New creates a new Exporter.

func NoSourcesError

func NoSourcesError(requestedIDs []int) error

NoSourcesError creates an error for when no sources are found in the data_sources table.

func NotConnectedError

func NotConnectedError() error

NotConnectedError creates an error for when export operation is attempted without database connection.

func OutputDirError

func OutputDirError(dir string, err error) error

OutputDirError creates an error for when the output directory cannot be created or accessed.

func SFGACreateError

func SFGACreateError(sourceID int, err error) error

SFGACreateError creates an error for when the SFGA archive cannot be created.

func SFGAWriteError

func SFGAWriteError(sourceID int, stage string, err error) error

SFGAWriteError creates an error for when data cannot be written to the SFGA archive.

func WorkDirError

func WorkDirError(sourceID int, err error) error

WorkDirError creates an error for when the temporary work directory for a source cannot be created or cleared.

Types

This section is empty.

Jump to